// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.ads.googleads.v16.resources;

import "google/ads/googleads/v16/common/lifecycle_goals.proto";
import "google/api/field_behavior.proto";
import "google/api/resource.proto";

option csharp_namespace = "Google.Ads.GoogleAds.V16.Resources";
option go_package = "google.golang.org/genproto/googleapis/ads/googleads/v16/resources;resources";
option java_multiple_files = true;
option java_outer_classname = "CustomerLifecycleGoalProto";
option java_package = "com.google.ads.googleads.v16.resources";
option objc_class_prefix = "GAA";
option php_namespace = "Google\\Ads\\GoogleAds\\V16\\Resources";
option ruby_package = "Google::Ads::GoogleAds::V16::Resources";

// Proto file describing the customer lifecycle resource.

// Account level customer lifecycle goal settings.
message CustomerLifecycleGoal {
  option (google.api.resource) = {
    type: "googleads.googleapis.com/CustomerLifecycleGoal"
    pattern: "customers/{customer_id}/customerLifecycleGoals"
  };

  // Lifecycle goal common settings, including existing user lists and existing
  // high lifetime value user lists, shared among different types of lifecycle
  // goals.
  message LifecycleGoalCustomerDefinitionSettings {
    // Output only. User lists which represent existing customers.
    repeated string existing_user_lists = 1 [
      (google.api.field_behavior) = OUTPUT_ONLY,
      (google.api.resource_reference) = {
        type: "googleads.googleapis.com/UserList"
      }
    ];

    // Output only. User lists which represent customers of high lifetime value.
    // In current stage, high lifetime value feature is in beta and this field
    // is read-only.
    repeated string high_lifetime_value_user_lists = 2 [
      (google.api.field_behavior) = OUTPUT_ONLY,
      (google.api.resource_reference) = {
        type: "googleads.googleapis.com/UserList"
      }
    ];
  }

  // Immutable. The resource name of the customer lifecycle goal.
  // Customer lifecycle resource names have the form:
  //
  // `customers/{customer_id}/customerLifecycleGoal`
  string resource_name = 1 [
    (google.api.field_behavior) = IMMUTABLE,
    (google.api.resource_reference) = {
      type: "googleads.googleapis.com/CustomerLifecycleGoal"
    }
  ];

  // Output only. Common lifecycle goal settings shared among different types of
  // lifecycle goals.
  LifecycleGoalCustomerDefinitionSettings
      lifecycle_goal_customer_definition_settings = 2
      [(google.api.field_behavior) = OUTPUT_ONLY];

  // Output only. Customer acquisition goal customer level value settings.
  google.ads.googleads.v16.common.LifecycleGoalValueSettings
      customer_acquisition_goal_value_settings = 3
      [(google.api.field_behavior) = OUTPUT_ONLY];
}
